// MIT License

// Copyright (c) 2023 Anton Tsitavets

// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

// https://github.com/Bayselonarrend/OpenIntegrations

// Набор тестов для YAxUnit

// @skip-check undefined-variable
// BSLLS:Typo-off
// BSLLS:LatinAndCyrillicSymbolInWord-off
// BSLLS:IncorrectLineBreak-off

// Раскомментировать, если выполняется OneScript
// #Использовать "../../../tools"
// #Использовать "../../../core"
// #Использовать asserts

#Область СлужебныйПрограммныйИнтерфейс

// Для YaxUnit

Процедура ИсполняемыеСценарии() Экспорт

    OPI_ПолучениеДанныхТестов.СформироватьТестыЯкс();

КонецПроцедуры

// Для Asserts

Функция ПолучитьСписокТестов(ЮнитТестирование) Экспорт // BSLLS:UnusedParameters-off

   Возврат OPI_ПолучениеДанныхТестов.СформироватьТестыАссертс();

КонецФункции

#Область Тесты

#Область Telegram

Процедура Телеграм_ПолучитьИнформациюБота() Экспорт
 
    Токен       = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    Результат   = OPI_Telegram.ПолучитьИнформациюБота(Токен);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьИнформациюБота");
        
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["username"]).Заполнено();
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура Телеграм_ПолучитьОбновления() Экспорт

    Токен       = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    Результат   = OPI_Telegram.ПолучитьОбновления(Токен);

    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьОбновления");
    
    OPI_Telegram.УдалитьWebhook(Токен);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие") .Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]).ИмеетТип("Массив");
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_УстановитьWebhook() Экспорт

    Токен       = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    URL         = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_URL");
    Результат   = OPI_Telegram.УстановитьWebhook(Токен, URL);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УстановитьWebhook");

    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]).Равно(Истина);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["description"]).Равно("Webhook was set");
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры
    
Процедура Телеграм_УдалитьWebhook() Экспорт

    Токен       = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен"); 
    Результат   = OPI_Telegram.УдалитьWebhook(Токен);

    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьWebhook");
        
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]).Равно(Истина);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["description"]).Равно("Webhook was deleted");
    
    OPI_Инструменты.Пауза(5);
                       
КонецПроцедуры

Процедура Телеграм_ОтправитьТекстовоеСообщение() Экспорт

    Токен    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDЧата   = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Чат");
    IDКанала = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");
    Тема     = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Тема");
    Форум    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Форум");
    
    ЧатТема  = Форум + "*" + Тема;
    Текст    = "Сообщение из автоматического теста";
    
    МассивРезультатов = Новый Массив;
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьТекстовоеСообщение(Токен, IDЧата, Текст));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьТекстовоеСообщение(Токен, IDКанала, Текст));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьТекстовоеСообщение(Токен, ЧатТема, Текст));
    
    IDСообщения = OPI_Инструменты.ЧислоВСтроку(МассивРезультатов[1]["result"]["message_id"]);
    OPI_ПолучениеДанныхТестов.ЗаписатьПараметр("Телеграм_IDСообщенияКанала", IDСообщения);
    
    Для Каждого Результат Из МассивРезультатов Цикл
        
        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьТекстовоеСообщение");        
        
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["text"]).Равно(Текст);
        
    КонецЦикла;

    OPI_Инструменты.Пауза(5);
        
КонецПроцедуры

Процедура Телеграм_ОтправитьКартинку() Экспорт

    Токен    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDЧата   = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Чат");
    IDКанала = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");
    Тема     = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Тема");
    Форум    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Форум");  
    ЧатТема  = Форум + "*" + Тема;
    Текст    = "Сообщение из автоматического теста";
    Картинка = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Картинка");
    ИВФ      = ПолучитьИмяВременногоФайла("png");
    Картинка.Записать(ИВФ);
    
    МассивРезультатов = Новый Массив;
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьКартинку(Токен, IDЧата  , Текст, Картинка));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьКартинку(Токен, ЧатТема , Текст, Картинка));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьКартинку(Токен, IDКанала, Текст, ИВФ));
    
    Для Каждого Результат Из МассивРезультатов Цикл

        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьКартинку");
        
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие") .Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["caption"]).Равно(Текст);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["photo"]).ИмеетТип("Массив");
        
    КонецЦикла;
    
    УдалитьФайлы(ИВФ);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_ОтправитьВидео() Экспорт

    Токен    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDЧата   = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Чат");
    IDКанала = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");
    Текст    = "Сообщение из автоматического теста";
    Видео    = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Видео");
    ИВФ      = ПолучитьИмяВременногоФайла("mp4");
    Видео.Записать(ИВФ);
    
    МассивРезультатов = Новый Массив;
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьВидео(Токен, IDЧата  , Текст, Видео));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьВидео(Токен, IDКанала, Текст, Видео));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьВидео(Токен, IDЧата  , Текст, ИВФ));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьВидео(Токен, IDКанала, Текст, ИВФ));
    
    Для Каждого Результат Из МассивРезультатов Цикл

        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьВидео");
        
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["caption"]).Равно(Текст);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["video"]["mime_type"]).Равно("video/mp4");
        
    КонецЦикла;
    
    УдалитьФайлы(ИВФ);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_ОтправитьАудио() Экспорт

    Токен    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDЧата   = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Чат");
    IDКанала = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");
    Текст    = "Сообщение из автоматического теста";
    Аудио    = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Аудио");
    ИВФ      = ПолучитьИмяВременногоФайла("mp3");
    Аудио.Записать(ИВФ);
    
    МассивРезультатов = Новый Массив;
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьАудио(Токен, IDЧата  , Текст, Аудио));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьАудио(Токен, IDКанала, Текст, Аудио));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьАудио(Токен, IDЧата  , Текст, ИВФ));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьАудио(Токен, IDКанала, Текст, ИВФ));
    
    Для Каждого Результат Из МассивРезультатов Цикл

        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьАудио");
        
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["caption"]).Равно(Текст);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["audio"]["mime_type"]).Равно("audio/mpeg");
        
    КонецЦикла;
    
    УдалитьФайлы(ИВФ);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_ОтправитьДокумент() Экспорт

    Токен    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDЧата   = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Чат");
    IDКанала = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");
    Текст    = "Сообщение из автоматического теста";
    Документ = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Документ");
    ИВФ      = ПолучитьИмяВременногоФайла("docx");
    Документ.Записать(ИВФ);
    
    МассивРезультатов = Новый Массив;
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьДокумент(Токен, IDЧата  , Текст, Документ));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьДокумент(Токен, IDКанала, Текст, Документ));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьДокумент(Токен, IDЧата  , Текст, ИВФ));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьДокумент(Токен, IDКанала, Текст, ИВФ));
    
    Для Каждого Результат Из МассивРезультатов Цикл

        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьДокумент");
        
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["caption"]).Равно(Текст);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["document"]).ИмеетТип("Соответствие").Заполнено();
        
    КонецЦикла;
    
    УдалитьФайлы(ИВФ);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_ОтправитьГифку() Экспорт

    Result   = "result";
    Токен    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDЧата   = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Чат");
    IDКанала = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");
    Текст    = "Сообщение из автоматического теста";
    Гифка    = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Гифка");
    ИВФ      = ПолучитьИмяВременногоФайла("gif");
    Гифка.Записать(ИВФ);
    
    МассивРезультатов = Новый Массив;
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьГифку(Токен, IDЧата  , Текст, Гифка));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьГифку(Токен, IDКанала, Текст, Гифка));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьГифку(Токен, IDЧата  , Текст, ИВФ));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьГифку(Токен, IDКанала, Текст, ИВФ));
    
    Для Каждого Результат Из МассивРезультатов Цикл

        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьГифку");
        
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Result]["caption"]).Равно(Текст);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Result]["document"]).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Result]["animation"]["mime_type"]).Равно("video/mp4");
        
    КонецЦикла;
    
    УдалитьФайлы(ИВФ);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_ОтправитьМедиагруппу() Экспорт
 
    Токен    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDЧата   = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Чат");
    IDКанала = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");
    Текст    = "Сообщение из автоматического теста";
    
    Картинка     = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Картинка");
    ИВФ_Картинка = ПолучитьИмяВременногоФайла("png");
    Картинка.Записать(ИВФ_Картинка);
    
    Видео        = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Видео");
    ИВФ_Видео    = ПолучитьИмяВременногоФайла("mp4");
    Видео.Записать(ИВФ_Видео);
        
    МедиагруппаЧат    = Новый Соответствие;
    МедиагруппаЧат.Вставить(Картинка , "photo");
    МедиагруппаЧат.Вставить(ИВФ_Видео, "video");
    
    МедиагруппаКанал = Новый Соответствие;
    МедиагруппаКанал.Вставить(ИВФ_Картинка, "photo");   
    МедиагруппаКанал.Вставить(Видео       , "video");
    
    МассивРезультатов = Новый Массив;
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьМедиагруппу(Токен, IDЧата, Текст, МедиагруппаЧат));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьМедиагруппу(Токен, IDКанала, Текст, МедиагруппаКанал));
    
    Для Каждого Результат Из МассивРезультатов Цикл

        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьМедиагруппу");
        
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]).ИмеетТип("Массив");
        
    КонецЦикла;

    УдалитьФайлы(ИВФ_Картинка);
    УдалитьФайлы(ИВФ_Видео);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_ОтправитьМестоположение() Экспорт
 
    Токен    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDЧата   = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Чат");
    IDКанала = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");
    Ширина   = "48.87373649724122";
    Долгота  = "48.87373649724122";

    МассивРезультатов = Новый Массив;
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьМестоположение(Токен, IDЧата  , Ширина, Долгота));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьМестоположение(Токен, IDКанала, Ширина, Долгота));
    
    Для Каждого Результат Из МассивРезультатов Цикл
        
        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьМестоположение");
        
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["location"]).ИмеетТип("Соответствие").Заполнено();
        
    КонецЦикла;
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_ОтправитьКонтакт() Экспорт
 
    Токен    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDЧата   = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Чат");
    IDКанала = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");
    Имя      = "Петр";
    Фамилия  = "Петров";
    Телефон  = "88005553535";
    
    МассивРезультатов = Новый Массив;

    OPI_Инструменты.Пауза(20);
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьКонтакт(Токен, IDЧата  , Имя, Фамилия, Телефон));
    OPI_Инструменты.Пауза(20);
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьКонтакт(Токен, IDКанала, Имя, Фамилия, Телефон));
    
    Для Каждого Результат Из МассивРезультатов Цикл
                
        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьКонтакт");
        
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["contact"]).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["contact"]["first_name"]).Равно(Имя);
        
    КонецЦикла;
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_ОтправитьОпрос() Экспорт
 
    Токен    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDЧата   = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Чат");
    IDКанала = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");
    
    Вопрос   = "Какой ваш любимый цвет?";
    
    МассивОтветов     = Новый Массив;
    МассивОтветов.Добавить("Красный");
    МассивОтветов.Добавить("Желтый");
    МассивОтветов.Добавить("Зеленый");
    
    МассивРезультатов = Новый Массив;
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьОпрос(Токен, IDЧата  , Вопрос, МассивОтветов, Ложь));
    МассивРезультатов.Добавить(OPI_Telegram.ОтправитьОпрос(Токен, IDКанала, Вопрос, МассивОтветов, Истина));
    
    Для Каждого Результат Из МассивРезультатов Цикл

        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьОпрос");
                
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["poll"]).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["poll"]["question"]).Равно(Вопрос);
        
    КонецЦикла;
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_ПереслатьСообщение() Экспорт
 
    Токен       = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDЧата      = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Чат");
    IDКанала    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");
    IDСообщения = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_IDСообщенияКанала");
    IDСообщения = Число(IDСообщения);
    
    Результат = OPI_Telegram.ПереслатьСообщение(Токен, IDСообщения, IDКанала, IDЧата);

    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПереслатьСообщение");
        
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]["forward_origin"]["message_id"]).Равно(IDСообщения);
    
    OPI_Инструменты.Пауза(5);
        
КонецПроцедуры

Процедура Телеграм_БанРазбан() Экспорт
 
    Токен       = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDЧата      = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Чат");
    IDКанала    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");
    
    Результат = OPI_Telegram.Бан(Токен, IDКанала, IDЧата);

    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "Бан");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["description"]).Равно("Bad Request: can't remove chat owner");
    
    Результат = OPI_Telegram.Разбан(Токен, IDКанала, IDЧата);

    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "Разбан");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["description"]).Равно("Bad Request: can't remove chat owner");
        
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура Телеграм_СоздатьСсылкуПриглашение() Экспорт
 
    Result        = "result";
    Час           = 3600;
    Сутки         = Час * 24;
    ТекущаяДата   = OPI_Инструменты.ПолучитьТекущуюДату();
    Токен         = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDКанала      = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");
    Заголовок     = "Ссылка " + Строка(ТекущаяДата); 
    Истечение     = ТекущаяДата + Сутки;
    UnixИстечение = OPI_Инструменты.UNIXTime(Истечение);
    UnixИстечение = СтрЗаменить(UnixИстечение, ",", "");
    UnixИстечение = Лев(UnixИстечение, 10);
    UnixИстечение = Число(UnixИстечение);
                                              
    Результат = OPI_Telegram.СоздатьСсылкуПриглашение(Токен, IDКанала, Заголовок, Истечение, 200);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьСсылкуПриглашение");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Result]["member_limit"]).Равно(200);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Result]["name"]).Равно(Заголовок);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Result]["expire_date"]).Равно(UnixИстечение);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_ЗакрепитьОткрепитьСообщение() Экспорт
 
    Токен         = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDКанала      = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");
    IDСообщения   = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_IDСообщенияКанала");
    
    МассивРезультатов = Новый Массив;
    МассивРезультатов.Добавить(OPI_Telegram.ЗакрепитьСообщение(Токен, IDКанала, IDСообщения));
    МассивРезультатов.Добавить(OPI_Telegram.ОткрепитьСообщение(Токен, IDКанала, IDСообщения));
    
    Для Каждого Результат Из МассивРезультатов Цикл
        
        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "Закрепить/Открепить Сообщение");
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]).Равно(Истина);
        
    КонецЦикла;
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_ПолучитьЧислоУчастников() Экспорт
 
    Токен         = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    IDКанала      = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Канал");

    Результат  = OPI_Telegram.ПолучитьЧислоУчастников(Токен, IDКанала);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьЧислоУчастников");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]).ИмеетТип("Число");
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_ПолучитьСписокАватаровФорума() Экспорт
 
    Токен       = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    Результат   = OPI_Telegram.ПолучитьСписокИконокАватаров(Токен);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСписокИконокАватаров");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура Телеграм_СоздатьУдалитьТемуФорума() Экспорт
 
    Ok_             = "ok";
    Result          = "result";
    ТипСоответствие = Тип("Соответствие");
    
    Токен       = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    Чат         = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Форум");
    Имя         = "Тестовая тема";
    НовоеИмя    = "Новый тестовый заголовок";
    Иконка      = "5357419403325481346";
    НовяИконка  = "5310132165583840589";
    
    Результат = OPI_Telegram.СоздатьТемуФорума(Токен, Чат, Имя, Иконка);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьТемуФорума");
    
    Тема      = Результат[Result]["message_thread_id"];
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Ok_]).Равно(Истина);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Result]["name"]).Равно(Имя);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Result]["icon_custom_emoji_id"]).Равно(Иконка);
        
    Результат = OPI_Telegram.ИзменитьТемуФорума(Токен, Чат, Тема, НовоеИмя, НовяИконка);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ИзменитьТемуФорума");
        
    Проверка_ТелеграмИстина(Результат);
    
    OPI_Инструменты.Пауза(5);
        
    Результат = OPI_Telegram.ЗакрытьТемуФорума(Токен, Чат, Тема);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ЗакрытьТемуФорума");
    
    Проверка_ТелеграмИстина(Результат);
    
    OPI_Инструменты.Пауза(25);
        
    Результат = OPI_Telegram.ОткрытьТемуФорума(Токен, Чат, Тема);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОткрытьТемуФорума");
        
    Проверка_ТелеграмИстина(Результат);
        
    OPI_Инструменты.Пауза(25);

    Результат = OPI_Telegram.УдалитьТемуФорума(Токен, Чат, Тема);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьТемуФорума");
        
    Проверка_ТелеграмИстина(Результат);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_ОткрытьЗакрытьГлавнуюТему() Экспорт
 
    Токен    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    Чат      = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Форум");

    Результат = OPI_Telegram.ОткрытьТемуФорума(Токен, Чат);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОткрытьТемуФорума");
    
    Результат = OPI_Telegram.ЗакрытьТемуФорума(Токен, Чат);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ЗакрытьТемуФорума");
        
    Проверка_ТелеграмИстина(Результат);
    
    OPI_Инструменты.Пауза(5);
    
    Результат = OPI_Telegram.ОткрытьТемуФорума(Токен, Чат);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОткрытьТемуФорума");
    
    Проверка_ТелеграмИстина(Результат);
    
    OPI_Инструменты.Пауза(5);
    
    Результат = OPI_Telegram.ОчиститьСписокЗакрепленныхСообщенийТемы(Токен, Чат);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОчиститьСписокЗакрепленныхСообщенийТемы");
    
    Проверка_ТелеграмИстина(Результат);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_СкрытьПоказатьГлавнуюТему() Экспорт
 
    Токен    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    Чат      = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Форум");

    Результат = OPI_Telegram.СкрытьГлавнуюТемуФорума(Токен, Чат);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СкрытьГлавнуюТемуФорума");
    
    Проверка_ТелеграмИстина(Результат);
    
    OPI_Инструменты.Пауза(5);

    Результат = OPI_Telegram.ПоказатьГлавнуюТемуФорума(Токен, Чат);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПоказатьГлавнуюТемуФорума");
    
    Проверка_ТелеграмИстина(Результат);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Телеграм_ИзменитьИмяГлавнойТемы() Экспорт
 
    Заголовок = "Новое имя главной темы " + Строка(Новый УникальныйИдентификатор);
    Токен     = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Токен");
    Чат       = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Телеграм_Форум");

    Результат = OPI_Telegram.ИзменитьИмяГлавнойТемыФорума(Токен, Чат, Заголовок);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ИзменитьИмяГлавнойТемыФорума");
    
    Проверка_ТелеграмИстина(Результат);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

#КонецОбласти

#Область ВК

Процедура ВК_СоздатьСсылкуТокена() Экспорт
 
    Приложение = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ВК_Приложение");
    Результат  = OPI_VK.СоздатьСсылкуПолученияТокена(Приложение);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьСсылкуПолученияТокена");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат) 
        .ИмеетТип("Строка")
        .Заполнено();
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура ВК_СоздатьУдалитьПост() Экспорт
 
    Response  = "response";
    Параметры = ПолучитьПараметрыВК();
    Текст     = "Пост из автотеста";
    URL       = "https://github.com/Bayselonarrend/OpenIntegrations";
    Картинка  = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Картинка");
    ИВФ       = ПолучитьИмяВременногоФайла("png");   
    Картинка.Записать(ИВФ);
    
    МассивРезультатов = Новый Массив;
    
    МассивРезультатов.Добавить(OPI_VK.СоздатьПост(Текст, Картинка, Ложь  ,    , Параметры));
    OPI_Инструменты.Пауза(5);
    
    МассивРезультатов.Добавить(OPI_VK.СоздатьПост(Текст, ИВФ     , Истина, URL, Параметры));
    OPI_Инструменты.Пауза(5);
    
    Для Каждого Результат Из МассивРезультатов Цикл

        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьПост");
    
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]["post_id"]).ИмеетТип("Число").Заполнено();
            
        ИДПоста   = Результат[Response]["post_id"];
        Результат = OPI_VK.УдалитьПост(ИДПоста, Параметры);

        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьПост");
                
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат) .ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]).ИмеетТип("Число").Равно(1);
            
    КонецЦикла;
    
    УдалитьФайлы(ИВФ);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура ВК_СоздатьОпрос() Экспорт
 
    Параметры = ПолучитьПараметрыВК();
    Вопрос    = "Вопрос из автотеста";
    
    МассивВариантов = Новый Массив;
    МассивВариантов.Добавить("Вариант 1");
    МассивВариантов.Добавить("Вариант 2");
    МассивВариантов.Добавить("Вариант 3");
    
    Результат = OPI_VK.СоздатьОпрос(Вопрос, МассивВариантов, , Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьОпрос");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["response"]["post_id"]).ИмеетТип("Число").Заполнено();
        
    ИДПоста  = Результат["response"]["post_id"];
    OPI_VK.УдалитьПост(ИДПоста, Параметры);
    
    OPI_Инструменты.Пауза(10);
       
КонецПроцедуры

Процедура ВК_СохранитьУдалитьКартинку() Экспорт
 
    Параметры        = ПолучитьПараметрыВК();
    Имя              = "Альбом из автотеста";
    Описание         = "Новый альбом из автотеста";
    ОписаниеКартинки = "Картинка автотест";
    Картинка         = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Картинка");
    ИВФ              = ПолучитьИмяВременногоФайла("png"); 
    ТипСоответствие  = Тип("Соответствие");  
    Response         = "response";
    Картинка.Записать(ИВФ);
      
    Результат = OPI_VK.СоздатьАльбом(Имя, Описание, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьАльбом");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]["description"]).Равно(Описание);
        
    ИДАльбома  = Результат[Response]["id"];
    
    МассивРезультатов = Новый Массив;
    
    МассивРезультатов.Добавить(OPI_VK.СохранитьКартинкуВАльбом(ИДАльбома, Картинка, ОписаниеКартинки, Параметры));
    OPI_Инструменты.Пауза(5);
    
    МассивРезультатов.Добавить(OPI_VK.СохранитьКартинкуВАльбом(ИДАльбома, ИВФ     , ОписаниеКартинки, Параметры));
    OPI_Инструменты.Пауза(5);
    
    Для Каждого Результат Из МассивРезультатов Цикл
        
        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СохранитьКартинкуВАльбом");
        
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие).Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response][0]["text"]).Равно(ОписаниеКартинки);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response][0]["album_id"]).Равно(ИДАльбома);
        
        ИДКартинки  = Результат[Response][0]["id"];
        Результат    = OPI_VK.УдалитьКартинку(ИДКартинки, Параметры);
        
        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьКартинку");
        
        Проверка_ВКИстина(Результат);
        
    КонецЦикла;
    
    Результат = OPI_VK.УдалитьАльбом(ИДАльбома, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьАльбом");
        
    Проверка_ВКИстина(Результат);
        
    УдалитьФайлы(ИВФ);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура ВК_СоздатьИсторию() Экспорт
 
    Параметры = ПолучитьПараметрыВК();
    URL       = "https://github.com/Bayselonarrend/OpenIntegrations";
    Картинка  = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Картинка");
    ИВФ       = ПолучитьИмяВременногоФайла("png");   
    Картинка.Записать(ИВФ);
    
    МассивРезультатов = Новый Массив;
    
    МассивРезультатов.Добавить(OPI_VK.СоздатьИсторию(ИВФ          , URL, Параметры));
    OPI_Инструменты.Пауза(5);
    
    МассивРезультатов.Добавить(OPI_VK.СоздатьИсторию(Картинка,    , Параметры));
    OPI_Инструменты.Пауза(5);
    
    Для Каждого Результат Из МассивРезультатов Цикл
        
        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьИсторию");
        
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["response"]["count"]).ИмеетТип("Число").Равно(1);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["response"]["items"]).ИмеетТип("Массив").Заполнено();
            
    КонецЦикла;
    
    УдалитьФайлы(ИВФ);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура ВК_МетодыОбсуждений() Экспорт
 
    Параметры       = ПолучитьПараметрыВК();
    Название        = "Обсуждение из автотеста";
    Сообщение       = "Сообщение из автотеста";
    ТипСоответствие = Тип("Соответствие");
    ТипЧисло        = Тип("Число");
    Response        = "response";
    
    Результат = OPI_VK.СоздатьОбсуждение(Название, Сообщение, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьОбсуждение");
    
    OPI_Инструменты.Пауза(5);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]).ИмеетТип(ТипЧисло).Заполнено();
    
    ИДОбсуждения = Результат[Response];    
    Результат    = OPI_VK.ЗакрытьОбсуждение(ИДОбсуждения, Ложь, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ЗакрытьОбсуждение");
        
    Проверка_ВКИстина(Результат);
        
    Результат = OPI_VK.ОткрытьОбсуждение(ИДОбсуждения, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОткрытьОбсуждение");
        
    OPI_Инструменты.Пауза(5);
    
    Проверка_ВКИстина(Результат);
        
    Результат = OPI_VK.НаписатьВОбсуждение(ИДОбсуждения, Сообщение, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "НаписатьВОбсуждение");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]).ИмеетТип(ТипЧисло).Заполнено();
       
    Результат = OPI_VK.ЗакрытьОбсуждение(ИДОбсуждения, Истина, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ЗакрытьОбсуждение");
        
    OPI_Инструменты.Пауза(5);
    Проверка_ВКИстина(Результат);
    
    OPI_Инструменты.Пауза(5);
        
КонецПроцедуры

Процедура ВК_ЛайкРепостКоммент() Экспорт
 
    Параметры       = ПолучитьПараметрыВК();
    Текст           = "Пост из автотеста";
    Сообщение       = "Сообщение из автотеста";
    ТипСоответствие = Тип("Соответствие");
    ТипЧисло        = Тип("Число");
    Response        = "response";
    
    Результат = OPI_VK.СоздатьПост(Текст, Новый Массив, , , Параметры);
    
    ИДПоста   = Результат[Response]["post_id"];    
    Результат = OPI_VK.ПоставитьЛайк(ИДПоста, , Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПоставитьЛайк");
    
    OPI_Инструменты.Пауза(5);
      
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]["likes"]).ИмеетТип(ТипЧисло).Заполнено();
        
    ВнешнийПост  = 2571;
    ВнешняяСтена = -218704372;
        
    Результат = OPI_VK.СделатьРепост(ВнешнийПост, ВнешняяСтена, , , Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СделатьРепост");
    
    OPI_Инструменты.Пауза(5);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]["success"]).ИмеетТип(ТипЧисло).Равно(1);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]["wall_repost_count"]).ИмеетТип(ТипЧисло).Равно(1); 
        
    Результат  = OPI_VK.НаписатьКомментарий(ИДПоста, Параметры["owner_id"], Сообщение, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "НаписатьКомментарий");
        
    OPI_Инструменты.Пауза(5);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]["comment_id"]).ИмеетТип(ТипЧисло).Заполнено();
   
    OPI_VK.УдалитьПост(ИДПоста, Параметры);
    OPI_VK.УдалитьПост(Результат[Response]["post_id"], Параметры);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура ВК_ПолучитьСтатистику() Экспорт
 
    ТекущаяДата     = OPI_Инструменты.ПолучитьТекущуюДату();
    Параметры       = ПолучитьПараметрыВК();
    Дата0           = НачалоДня(ТекущаяДата);
    Дата1           = КонецДня(Дата0);
    ТипСоответствие = Тип("Соответствие");
     
    Результат = OPI_VK.ПолучитьСтатистику(Дата0, Дата1, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСтатистику");
        
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["response"][0]["visitors"]).ИмеетТип(ТипСоответствие).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["response"][0]["reach"]).ИмеетТип(ТипСоответствие).Заполнено();
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура ВК_ПолучитьСтатистикуПостов() Экспорт
 
    Параметры    = ПолучитьПараметрыВК();
    
    МассивПостов = Новый Массив;
    МассивПостов.Добавить(214);
    МассивПостов.Добавить(215);
    
    Результат = OPI_VK.ПолучитьСтатистикуПостов(МассивПостов, Параметры);

    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСтатистикуПостов");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Массив").ИмеетДлину(2);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура ВК_СоздатьРекламнуюКампанию() Экспорт
 
    Параметры       = ПолучитьПараметрыВК();
    ИДКабинета      = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ВК_Кабинет");
    Наименование    = "Тестовая кампания";
    ТипСоответствие = Тип("Соответствие");
    ТипЧисло        = Тип("Число");
    Response        = "response";
    UID             = "id";
        
    Результат    = OPI_VK.СоздатьРекламнуюКампанию(ИДКабинета, Наименование, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьРекламнуюКампанию");
    
    Результат    = Результат[Response][0];
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие); 
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["error_code"]).ИмеетТип(ТипЧисло).Равно(602);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[UID]).ИмеетТип(ТипЧисло).Заполнено();
        
    ИДКампании  = Результат[UID];
    ИДКатегории = 126;
    Лимит       = 150;
    
    Результат = OPI_VK.СоздатьПост(Наименование, Новый Массив, , , Параметры); 
    ИДПоста   = Результат[Response]["post_id"]; 
        
    Результат   = OPI_VK.СоздатьРекламноеОбъявление(ИДКампании
        , Лимит
        , ИДКатегории
        , ИДПоста
        , ИДКабинета
        , Параметры);
        
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьРекламноеОбъявление");
            
    Результат   = Результат[Response][0];
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие); 
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["error_code"]).ИмеетТип(ТипЧисло).Равно(602);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[UID]).ИмеетТип(ТипЧисло).Заполнено();
        
    ИДОбъявления = Результат[UID];
    Результат    = OPI_VK.ПриостановитьРекламноеОбъявление(ИДКабинета, ИДОбъявления, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПриостановитьРекламноеОбъявление");
    
    Результат    = Результат[Response][0];
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие); 
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[UID]).ИмеетТип(ТипЧисло).Заполнено();
 
    OPI_VK.УдалитьПост(ИДПоста, Параметры);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура ВК_ОтправитьСообщение() Экспорт
 
    Параметры    = ПолучитьПараметрыВК();
    Пользователь = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ВК_Пользователь");
    Токен        = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ВК_КТ");
    Текст        = "Сообщение из автотеста";
    
    МассивКнопок = Новый Массив;
    МассивКнопок.Добавить("Кнопка 1");
    МассивКнопок.Добавить("Кнопка 2"); 
    
    Клавиатура = OPI_VK.СформироватьКлавиатуру(МассивКнопок);
    Результат  = OPI_VK.НаписатьСообщение(Текст, Пользователь, Токен, Клавиатура, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "НаписатьСообщение");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие"); 
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["response"]).ИмеетТип("Число").Заполнено();
    
    OPI_Инструменты.Пауза(5);
  
КонецПроцедуры

Процедура ВК_ПолучитьКатегорииТоваров() Экспорт
 
    Параметры = ПолучитьПараметрыВК();
    Результат = OPI_VK.ПолучитьСписокКатегорийТоваров(Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСписокКатегорийТоваров");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат) 
        .ИмеетТип("Соответствие")
        .Заполнено();
        
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура ВК_СоздатьТоварПодборку() Экспорт
 
    Параметры       = ПолучитьПараметрыВК();
    ТипСоответствие = Тип("Соответствие");
    ТипЧисло        = Тип("Число");
    Response        = "response";
    Картинка        = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Картинка");
    ИВФ             = ПолучитьИмяВременногоФайла("png");   
    Картинка.Записать(ИВФ);
    
    Результат = OPI_VK.СоздатьПодборкуТоваров("Тестовая подборка"
        , Картинка
        , Истина
        , Ложь
        , Параметры);  
        
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьПодборкуТоваров");
    
    OPI_Инструменты.Пауза(5);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]["albums_count"]).ИмеетТип(ТипЧисло).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]["market_album_id"]).ИмеетТип(ТипЧисло).Заполнено();
             
    ИДПодборки = Результат[Response]["market_album_id"];
    
    Результат  = OPI_VK.ИзменитьПодборкуТоваров("Измененная подборка", ИДПодборки, , , , Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ИзменитьПодборкуТоваров");
    
    OPI_Инструменты.Пауза(5);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]).ИмеетТип(ТипЧисло).Равно(1);
 
    МассивКартинок = Новый Массив;
    МассивКартинок.Добавить(ИВФ);
    МассивКартинок.Добавить(Картинка);
    
    Товар = Новый Соответствие();
    Товар.Вставить("Имя"                , "Тестовый товар");    
    Товар.Вставить("Описание"           , "Описание товара");
    Товар.Вставить("Категория"          , "20173");           
    Товар.Вставить("Цена"               , 1);                
    Товар.Вставить("СтараяЦена"         , 15);     
    Товар.Вставить("ОсновноеФото"       , Картинка);                   
    Товар.Вставить("URL"                , "https://github.com/Bayselonarrend/OpenIntegrations");     
    Товар.Вставить("ДополнительныеФото" , МассивКартинок);     
    Товар.Вставить("ГлавныйВГруппе"     , Истина);                 
    Товар.Вставить("Ширина"             , 20);     
    Товар.Вставить("Высота"             , 30);     
    Товар.Вставить("Глубина"            , 40);     
    Товар.Вставить("Вес"                , 100);
    Товар.Вставить("SKU"                , "12345");
    Товар.Вставить("ДоступныйОстаток"   , "10");
    
    Результат = OPI_VK.ДобавитьТовар(Товар, ИДПодборки, Параметры);                // Добавление товара
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ДобавитьТовар");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]["market_item_id"]).ИмеетТип(ТипЧисло).Заполнено();
        
    ИДТовара  = Результат[Response]["market_item_id"];
    
    Товар = Новый Соответствие;
    Товар.Вставить("Имя", "Тестовый товар измененный");
    
    Результат = OPI_VK.ИзменитьТовар(ИДТовара, Товар, , Параметры);                // Изменение товара
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ИзменитьТовар");
    
    Проверка_ВКИстина(Результат);
    
    Результат = OPI_VK.ДобавитьТоварВПодборку(ИДТовара, ИДПодборки, Параметры);    // Добавление в подборку
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ДобавитьТоварВПодборку");
    
    OPI_Инструменты.Пауза(5);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]).ИмеетТип(ТипЧисло).Заполнено();
        
    Результат = OPI_VK.УдалитьТоварИзПодборки(ИДТовара, ИДПодборки, Параметры);    // Удаляет из подборки
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьТоварИзПодборки");
    
    OPI_Инструменты.Пауза(5);
    Проверка_ВКИстина(Результат);
        
    Результат = OPI_VK.УдалитьТовар(ИДТовара, Параметры);                          // Удаление товара
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьТовар");
    
    OPI_Инструменты.Пауза(5);
    Проверка_ВКИстина(Результат);
        
    Результат = OPI_VK.УдалитьПодборку(ИДПодборки, Параметры);                     // Уадление подборки
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьПодборку");
    
    OPI_Инструменты.Пауза(5);
    Проверка_ВКИстина(Результат);

    УдалитьФайлы(ИВФ);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура ВК_СоздатьТоварСоСвойствами() Экспорт
 
    Параметры       = ПолучитьПараметрыВК();
    ТипСоответствие = Тип("Соответствие");
    ТипЧисло        = Тип("Число");
    MII             = "market_item_id";
    Response        = "response";
    Желтый          = "Желтый";
    Красный         = "Красный";
    Картинка        = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Картинка");
    ИВФ             = ПолучитьИмяВременногоФайла("png");   
    Картинка.Записать(ИВФ);
    
    МассивВариантов = Новый Массив;
    МассивВариантов.Добавить(Желтый);
    МассивВариантов.Добавить("Синий");
    МассивВариантов.Добавить(Красный);
    
    Результат = OPI_VK.СоздатьСвойствоТовара("Цвет", Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьСвойствоТовара");
    
    OPI_Инструменты.Пауза(5);
    
    Свойство  = Результат[Response]["property_id"];
    Свойство  = OPI_Инструменты.ЧислоВСтроку(Свойство);
     
    СоответствиеСвойств = Новый Соответствие;
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]["property_id"]).ИмеетТип(ТипЧисло).Заполнено();
        
    Результат = OPI_VK.ИзменитьСвойствоТовара("Цвет (изм.)", Свойство, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ИзменитьСвойствоТовара");
    
    OPI_Инструменты.Пауза(5);
    
    Проверка_ВКИстина(Результат);
   
    Для Каждого Вариант Из МассивВариантов Цикл
        
        Результат = OPI_VK.ДобавитьВариантСвойстваТовара(Вариант, Свойство, Параметры);
        
        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ДобавитьВариантСвойстваТовара");
        
        OPI_Инструменты.Пауза(5);
        
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие);
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]["variant_id"]).ИмеетТип(ТипЧисло).Заполнено();
            
        ИДВарианта = Результат[Response]["variant_id"];
        СоответствиеСвойств.Вставить(Вариант, ИДВарианта);
        
        Результат = OPI_VK.ИзменитьВариантСвойстваТовара(Вариант + " (изм.)"
            , Свойство
            , ИДВарианта
            , Параметры);
            
        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ИзменитьВариантСвойстваТовара");
        
    Проверка_ВКИстина(Результат);
              
    КонецЦикла;
  
    МассивКартинок = Новый Массив;
    МассивКартинок.Добавить(ИВФ);
    МассивКартинок.Добавить(Картинка);
    
    Товар = Новый Соответствие();
    Товар.Вставить("Имя"                , "Тестовый товар (" + Желтый + ")");    
    Товар.Вставить("Описание"           , "Описание товара");
    Товар.Вставить("Категория"          , "20173");           
    Товар.Вставить("Цена"               , 1);                
    Товар.Вставить("СтараяЦена"         , 15);     
    Товар.Вставить("ОсновноеФото"       , Картинка);                   
    Товар.Вставить("URL"                , "https://github.com/Bayselonarrend/OpenIntegrations");     
    Товар.Вставить("ДополнительныеФото" , МассивКартинок);     
    Товар.Вставить("ГлавныйВГруппе"     , Истина);             
    Товар.Вставить("НомерГруппы"        , Неопределено);      
    Товар.Вставить("Ширина"             , 20);     
    Товар.Вставить("Высота"             , 30);     
    Товар.Вставить("Глубина"            , 40);     
    Товар.Вставить("Вес"                , 100);
    Товар.Вставить("SKU"                , 12345);
    Товар.Вставить("ДоступныйОстаток"   , "10");
    Товар.Вставить("ЗначенияСвойств"    , СоответствиеСвойств[Желтый]);
    
    Результат = OPI_VK.ДобавитьТовар(Товар, , Параметры);                // Добавление товара  
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ДобавитьТовар");
    
    OPI_Инструменты.Пауза(5);
    
    ИДЖелтого = Результат[Response]["market_item_id"];               
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response][MII]).ИмеетТип(ТипЧисло).Заполнено();
        
    Товар.Вставить("Имя"            , "Тестовый товар (" + Красный + ")");
    Товар.Вставить("ЗначенияСвойств", СоответствиеСвойств[Красный]);

    Результат  = OPI_VK.ДобавитьТовар(Товар, , Параметры);                // Добавление товара
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ДобавитьТовар");
      
    OPI_Инструменты.Пауза(5);
    
    ИДКрасного = Результат[Response][MII];               
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response][MII]).ИмеетТип(ТипЧисло).Заполнено();
        
    МассивТоваров = Новый Массив;
    МассивТоваров.Добавить(ИДЖелтого);
    МассивТоваров.Добавить(ИДКрасного);
    
    Результат = OPI_VK.ПолучитьТоварыПоИД(МассивТоваров, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьТоварыПоИД");
    
    OPI_Инструменты.Пауза(5);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]["items"]).ИмеетТип("Массив").ИмеетДлину(2);
        
    Результат = OPI_VK.СгруппироватьТовары(МассивТоваров, , Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СгруппироватьТовары");
    
    OPI_Инструменты.Пауза(5);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Response]["item_group_id"]).ИмеетТип(ТипЧисло).Заполнено();
       
    OPI_VK.УдалитьТовар(ИДЖелтого , Параметры);
    OPI_VK.УдалитьТовар(ИДКрасного, Параметры);
    
    Для Каждого Вариант Из СоответствиеСвойств Цикл
        
        Удаление = OPI_VK.УдалитьВариантСвойстваТовара(Вариант.Значение, Параметры);
        
        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьВариантСвойстваТовара");
        
        OPI_Инструменты.Пауза(5);
        Проверка_ВКИстина(Удаление);
        
    КонецЦикла;
        
    Удаление = OPI_VK.УдалитьСвойствоТовара(Свойство, Параметры);
   
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьСвойствоТовара");
        
    OPI_Инструменты.Пауза(5);
    
    Проверка_ВКИстина(Удаление);

    УдалитьФайлы(ИВФ);
    
КонецПроцедуры

Процедура ВК_ПолучитьСписокТоваров() Экспорт
 
    Параметры = ПолучитьПараметрыВК();
    Картинка  = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Картинка"); 
    
    МассивКартинок = Новый Массив;
    МассивКартинок.Добавить(Картинка);
    
    Товар = Новый Соответствие();
    Товар.Вставить("Имя"                , "Тестовый товар 2");    
    Товар.Вставить("Описание"           , "Описание товара");
    Товар.Вставить("Категория"          , "20173");           
    Товар.Вставить("Цена"               , 1);                
    Товар.Вставить("СтараяЦена"         , 15);     
    Товар.Вставить("ОсновноеФото"       , Картинка);                   
    Товар.Вставить("URL"                , "https://github.com/Bayselonarrend/OpenIntegrations");     
    Товар.Вставить("ДополнительныеФото" , МассивКартинок);     
    Товар.Вставить("ГлавныйВГруппе"     , Истина);             
    Товар.Вставить("НомерГруппы"        , Неопределено);      
    Товар.Вставить("Ширина"             , 20);     
    Товар.Вставить("Высота"             , 30);     
    Товар.Вставить("Глубина"            , 40);     
    Товар.Вставить("Вес"                , 100);
    Товар.Вставить("SKU"                , 12345);
    Товар.Вставить("ДоступныйОстаток"   , "10");
    
    Результат = OPI_VK.ДобавитьТовар(Товар, , Параметры);
    ИДТовара  = Результат["response"]["market_item_id"];
    OPI_Инструменты.Пауза(5);
    
    Результат = OPI_VK.ПолучитьСписокТоваров(, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСписокТоваров");
    
    OPI_Инструменты.Пауза(5);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат) 
        .ИмеетТип("Массив").Заполнено();
              
    OPI_VK.УдалитьТовар(ИДТовара, Параметры);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура ВК_ПолучитьСписокПодборок() Экспорт
 
    Параметры = ПолучитьПараметрыВК();
    Картинка  = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Картинка");    
    Результат = OPI_VK.СоздатьПодборкуТоваров("Тестовая подборка"
        , Картинка
        , Истина
        , Ложь
        , Параметры); 
     
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьПодборкуТоваров");
       
    ИДПодборки = Результат["response"]["market_album_id"];      
    Результат  = OPI_VK.ПолучитьСписокПодборок(Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСписокПодборок");
    
    OPI_Инструменты.Пауза(5);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат) 
        .ИмеетТип("Массив").Заполнено();
        
    OPI_VK.УдалитьПодборку(ИДПодборки, Параметры); 
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура ВК_ПолучитьСписокСвойств() Экспорт
 
    Параметры  = ПолучитьПараметрыВК();
    Результат  = OPI_VK.ПолучитьСписокСвойств(Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСписокСвойств");
    
    OPI_Инструменты.Пауза(5);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат) 
        .ИмеетТип("Массив").Заполнено();
        
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура ВК_ПолучитьСписокЗаказов() Экспорт
 
    Параметры  = ПолучитьПараметрыВК();
    Результат  = OPI_VK.ПолучитьСписокЗаказов(Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСписокЗаказов");
    
    OPI_Инструменты.Пауза(5);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат) 
        .ИмеетТип("Массив").Заполнено();
        
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

#КонецОбласти

#Область YandexDisk

Процедура ЯДиск_ПолучитьИнформациюОДиске() Экспорт
 
    Токен        = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ЯДиск_Токен");
    Соответствие = "Соответствие";
    
    Результат = OPI_YandexDisk.ПолучитьИнформациюОДиске(Токен);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьИнформациюОДиске");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(Соответствие).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["system_folders"]).ИмеетТип(Соответствие);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["user"]).ИмеетТип(Соответствие);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура ЯДиск_СоздатьПапку() Экспорт
 
   Токен = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ЯДиск_Токен");
   Путь  = "/" + Строка(Новый УникальныйИдентификатор);
   
   Результат = OPI_YandexDisk.СоздатьПапку(Токен, Путь);
   
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьПапку");
   
   OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
   OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["type"]).Равно("dir");
   OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["path"]).Равно("disk:" + Путь);
        
   OPI_YandexDisk.УдалитьОбъект(Токен, Путь, Ложь);
  
   OPI_Инструменты.Пауза(5);
  
КонецПроцедуры

Процедура ЯДиск_ЗагрузитьПоАдресуПолучитьОбъект() Экспорт
 
    Токен = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ЯДиск_Токен");
    Путь  = "/" + Строка(Новый УникальныйИдентификатор) + ".png";
    URL   = "https://raw.githubusercontent.com/Bayselonarrend/OpenIntegrations/main/Media/logo.png";

    OPI_YandexDisk.ЗагрузитьФайлПоURL(Токен, Путь, URL);
    OPI_Инструменты.Пауза(5);
        
    Результат = OPI_YandexDisk.ПолучитьОбъект(Токен, Путь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьОбъект");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["type"]).Равно("file");
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["path"]).Равно("disk:" + Путь);

     OPI_YandexDisk.УдалитьОбъект(Токен, Путь, Ложь);
     
     OPI_Инструменты.Пауза(5);
     
КонецПроцедуры

Процедура ЯДиск_ЗагрузитьУдалитьФайл() Экспорт
 
    Токен    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ЯДиск_Токен");
    Путь     = "/" + Строка(Новый УникальныйИдентификатор) + ".png";
    Картинка = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Картинка");
    ИВФ      = ПолучитьИмяВременногоФайла("png");
    Картинка.Записать(ИВФ);

    Результат = OPI_YandexDisk.ЗагрузитьФайл(Токен, Путь, Картинка, Истина);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ЗагрузитьФайл");
    
    Проверка_Пусто(Результат);
    OPI_Инструменты.Пауза(5);
    
    Результат = OPI_YandexDisk.УдалитьОбъект(Токен, Путь, Ложь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьОбъект");
    
    Проверка_Пусто(Результат);
    
    Результат = OPI_YandexDisk.ЗагрузитьФайл(Токен, Путь, ИВФ, Истина);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ЗагрузитьФайл");
    
    Проверка_Пусто(Результат);
    OPI_Инструменты.Пауза(5);
    
    Результат = OPI_YandexDisk.УдалитьОбъект(Токен, Путь, Ложь); 
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьОбъект");
    
    Проверка_Пусто(Результат);   

    УдалитьФайлы(ИВФ);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура ЯДиск_СоздатьКопиюОбъекта() Экспорт
 
    Токен           = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ЯДиск_Токен");
    ПутьОригинала   = "/" + Строка(Новый УникальныйИдентификатор) + ".png";
    ПутьКопии       = "/" + Строка(Новый УникальныйИдентификатор) + ".png";
    URL             = "https://raw.githubusercontent.com/Bayselonarrend/"
        + "OpenIntegrations/main/Media/logo.png";

    OPI_YandexDisk.ЗагрузитьФайлПоURL(Токен, ПутьОригинала, URL);
    OPI_Инструменты.Пауза(5);
      
    Результат = OPI_YandexDisk.СоздатьКопиюОбъекта(Токен, ПутьОригинала, ПутьКопии, Истина);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьКопиюОбъекта");
    
    OPI_Инструменты.Пауза(5);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["type"]).Равно("file");
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["path"]).Равно("disk:" + ПутьКопии);

     OPI_YandexDisk.УдалитьОбъект(Токен, ПутьОригинала, Ложь);
     OPI_YandexDisk.УдалитьОбъект(Токен, ПутьКопии, Ложь);
     
     OPI_Инструменты.Пауза(5);
     
КонецПроцедуры

Процедура ЯДиск_ПолучитьСсылкуНаСкачивание() Экспорт
 
    Токен = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ЯДиск_Токен");
    Путь  = "/" + Строка(Новый УникальныйИдентификатор) + ".png";
    URL   = "https://raw.githubusercontent.com/Bayselonarrend/OpenIntegrations/main/Media/logo.png";

    OPI_YandexDisk.ЗагрузитьФайлПоURL(Токен, Путь, URL);
    OPI_Инструменты.Пауза(5);
       
    Результат = OPI_YandexDisk.ПолучитьСсылкуДляСкачивания(Токен, Путь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСсылкуДляСкачивания");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["method"]).Равно("GET");
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["href"]).ИмеетТип("Строка").Заполнено();

    OPI_YandexDisk.УдалитьОбъект(Токен, Путь, Ложь);

КонецПроцедуры

Процедура ЯДиск_ПолучитьСписокФайлов() Экспорт
 
    Токен = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ЯДиск_Токен");
    Количество = 2;
    Отступ     = 1;
    
    Результат = OPI_YandexDisk.ПолучитьСписокФайлов(Токен, Количество, Отступ, "image");
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСписокФайлов");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["limit"]).Равно(Количество);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["offset"]).Равно(Отступ);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["items"]).ИмеетТип("Массив");
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура ЯДиск_ПереместитьОбъект() Экспорт
 
    Токен           = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ЯДиск_Токен");
    ПутьОригинала   = "/" + Строка(Новый УникальныйИдентификатор) + ".png";
    ПутьКопии       = "/" + Строка(Новый УникальныйИдентификатор) + ".png";
    URL             = "https://raw.githubusercontent.com/Bayselonarrend/"
        + "OpenIntegrations/main/Media/logo.png";

    OPI_YandexDisk.ЗагрузитьФайлПоURL(Токен, ПутьОригинала, URL);
    OPI_Инструменты.Пауза(15);
      
    Результат = OPI_YandexDisk.ПереместитьОбъект(Токен, ПутьОригинала, ПутьКопии, Истина);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПереместитьОбъект");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["type"]).Равно("file");
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["path"]).Равно("disk:" + ПутьКопии);

    OPI_YandexDisk.УдалитьОбъект(Токен, ПутьОригинала, Ложь);
    OPI_YandexDisk.УдалитьОбъект(Токен, ПутьКопии, Ложь);
    
    OPI_Инструменты.Пауза(5);
     
КонецПроцедуры

Процедура ЯДиск_ДействияПубличныхОбъектов() Экспорт
 
    PUrl         = "public_url";
    Соответствие = "Соответствие";
    Токен        = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ЯДиск_Токен");
    Путь         = "/" + Строка(Новый УникальныйИдентификатор) + ".png";
    URL          = "https://raw.githubusercontent.com/Bayselonarrend/OpenIntegrations/main/Media/logo.png";
    
    OPI_YandexDisk.ЗагрузитьФайлПоURL(Токен, Путь, URL);
    OPI_Инструменты.Пауза(5);
    
    МассивРезультатов = Новый Массив;
    
    МассивРезультатов.Добавить(OPI_YandexDisk.ОпубликоватьОбъект(Токен, Путь)); 
    ПубличныйURL      = МассивРезультатов[0][PUrl];
    
    Результат  = OPI_YandexDisk.ПолучитьСсылкуСкачиванияПубличногоОбъекта(Токен, ПубличныйURL);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСсылкуСкачиванияПубличногоОбъекта");
              
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(Соответствие).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["method"]).Равно("GET");
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["href"]).ИмеетТип("Строка").Заполнено();
    
    Результат   = OPI_YandexDisk.ПолучитьПубличныйОбъект(Токен, ПубличныйURL);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьПубличныйОбъект");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(Соответствие).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["type"]).Равно("file");
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["path"]).Равно("/");
    
    МассивРезультатов.Добавить(OPI_YandexDisk.СохранитьПубличныйОбъектНаДиск(Токен, ПубличныйURL));
                
    МассивРезультатов.Добавить(OPI_YandexDisk.ОтменитьПубликациюОбъекта(Токен, Путь));
    
    Счетчик = 0;
    Для Каждого Результат Из МассивРезультатов Цикл
        
        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "Изменение публикации");
            
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(Соответствие).Заполнено();
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["type"]).Равно("file");
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["path"]).Заполнено();
            
        Если Счетчик = 0 Тогда   
            OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[PUrl]).ИмеетТип("Строка").Заполнено();
        Иначе
            OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[PUrl]).ИмеетТип("Неопределено");
        КонецЕсли;
        
        Счетчик = Счетчик + 1;
        
    КонецЦикла;
     
    OPI_YandexDisk.УдалитьОбъект(Токен, Путь, Ложь);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура ЯДиск_ПолучитьСписокОпубликованных() Экспорт
 
    Токен = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ЯДиск_Токен");
    Количество = 2;
    Отступ     = 1;
    
    Результат = OPI_YandexDisk.ПолучитьСписокОпубликованныхОбъектов(Токен, Количество, Отступ);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСписокОпубликованныхОбъектов");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["limit"]).Равно(Количество);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["offset"]).Равно(Отступ);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["items"]).ИмеетТип("Массив");
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

#КонецОбласти

#Область GoogleWorkspace

Процедура ГВ_ПолучитьСсылкуАвторизации() Экспорт
 
    ClientID  = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_ClientID");    
    Результат = OPI_GoogleWorkspace.СформироватьСсылкуПолученияКода(ClientID);
            
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат)
        .ИмеетТип("Строка") 
        .Заполнено();
        
    OPI_ПолучениеДанныхТестов.ЗаписатьПараметр("Google_Link", Результат);
    
    OPI_Инструменты.Пауза(5);
        
КонецПроцедуры

Процедура ГВ_ПолучитьТокен() Экспорт
 
    ClientID      = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_ClientID");
    ClientSecret  = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_ClientSecret");
    Code          = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_Code");
    
    Результат = OPI_GoogleWorkspace.ПолучитьТокенПоКоду(ClientID, ClientSecret, Code);
           
    Если ЗначениеЗаполнено(Результат["access_token"])
        И ЗначениеЗаполнено(Результат["refresh_token"]) Тогда
        
        OPI_ПолучениеДанныхТестов.ЗаписатьПараметр("Google_Token"  , Результат["access_token"]);
        OPI_ПолучениеДанныхТестов.ЗаписатьПараметр("Google_Refresh", Результат["refresh_token"]);
    
    КонецЕсли;
    
    OPI_Инструменты.Пауза(5);
      
КонецПроцедуры

Процедура ГВ_ОбновитьТокен() Экспорт
 
    ClientID      = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_ClientID");
    ClientSecret  = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_ClientSecret");
    RefreshToken  = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_Refresh");
    
    Результат = OPI_GoogleWorkspace.ОбновитьТокен(ClientID, ClientSecret, RefreshToken);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие");                
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["access_token"]).Заполнено();
    
    OPI_ПолучениеДанныхТестов.ЗаписатьПараметр("Google_Token", Результат["access_token"]);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

#КонецОбласти

#Область GoogleCalendar

Процедура ГК_ПолучитьСписокКалендарей() Экспорт
 
    Токен     = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_Token");    
    Результат = OPI_GoogleCalendar.ПолучитьСписокКалендарей(Токен);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСписокКалендарей");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат)
        .ИмеетТип("Массив");

    OPI_Инструменты.Пауза(5);
            
КонецПроцедуры

Процедура ГК_СоздатьУдалитьКалендарь() Экспорт
 
    Токен                   = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_Token"); 
    Наименование            = "Тестовый календарь";
    Описание                = "Тестовое описание";
    НаименованиеИзмененное  = Наименование + " (изм.)";
    ТипСоответствие         = Тип("Соответствие");
    ТипСтрока               = Тип("Строка");
    Summary                 = "summary";
    Черный                  = "#000000";
    Желтый                  = "#ffd800";
    
    Результат = OPI_GoogleCalendar.СоздатьКалендарь(Токен, Наименование); 
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьКалендарь");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие); 
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Summary]).Равно(Наименование);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["id"]).ИмеетТип(ТипСтрока).Заполнено();
        
    Календарь = Результат["id"];
    
    Результат = OPI_GoogleCalendar.ИзменитьМетаданныеКалендаря(Токен
        , Календарь
        , НаименованиеИзмененное
        , Описание);
        
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ИзменитьМетаданныеКалендаря");
    
    Проверка_ГКОбъект(Результат, НаименованиеИзмененное, Описание);
        
    Результат = OPI_GoogleCalendar.ПолучитьМетаданныеКалендаря(Токен, Календарь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьМетаданныеКалендаря");  
    
    Проверка_ГКОбъект(Результат, НаименованиеИзмененное, Описание);

    Результат = OPI_GoogleCalendar.ДобавитьКалендарьВСписок(Токен, Календарь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ДобавитьКалендарьВСписок");
    
    Проверка_ГКОбъект(Результат, НаименованиеИзмененное, Описание);
    
    Результат = OPI_GoogleCalendar.ИзменитьКалендарьСписка(Токен, Календарь, Черный, Желтый, Ложь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ИзменитьКалендарьСписка");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие); 
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Summary]).Равно(НаименованиеИзмененное);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["foregroundColor"]).Равно(Черный);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["backgroundColor"]).Равно(Желтый);
        
    Результат = OPI_GoogleCalendar.ПолучитьКалендарьСписка(Токен, Календарь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьКалендарьСписка");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип(ТипСоответствие); 
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Summary]).Равно(НаименованиеИзмененное);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["foregroundColor"]).Равно(Черный);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["backgroundColor"]).Равно(Желтый);

    Результат = OPI_GoogleCalendar.ОчиститьОсновнойКалендарь(Токен);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОчиститьОсновнойКалендарь");
    
    Проверка_Пусто(Результат);
    
    Результат = OPI_GoogleCalendar.УдалитьКалендарьИзСписка(Токен, Календарь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьКалендарьИзСписка");
    
    Проверка_Пусто(Результат);
    
    Результат = OPI_GoogleCalendar.УдалитьКалендарь(Токен, Календарь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьКалендарь");
    
    Проверка_Пусто(Результат);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура ГК_СоздатьУдалитьСобытие() Экспорт
 
    ТекущаяДата     = OPI_Инструменты.ПолучитьТекущуюДату();
    Токен           = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_Token"); 
    Календарь       = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_Календарь");
    Наименование    = "Новое событие";
    Описание        = "Описание тестового события";
    ОписаниеИзм     = "Описание тестового события (изм.)";
    UID             = "id";
    Час             = 3600;

    Вложения        = Новый Соответствие;
    
    Вложения.Вставить("Картинка1"
        , "https://opi.neocities.org/assets/images/logo_long-e8fdcca6ff8b32e679ea49a1ccdd3eac.png");
    Вложения.Вставить("Картинка2"
        , "https://github.com/Bayselonarrend/OpenIntegrations/raw/main/Media/logo.png?v1");
    
    СоответствиеСобытия = Новый Соответствие;
    СоответствиеСобытия.Вставить("Описание"                 , Описание);
    СоответствиеСобытия.Вставить("Заголовок"                , Наименование);
    СоответствиеСобытия.Вставить("МестоПроведения"          , "В офисе");
    СоответствиеСобытия.Вставить("ДатаНачала"               , ТекущаяДата);
    СоответствиеСобытия.Вставить("ДатаОкончания"            , СоответствиеСобытия["ДатаНачала"] + Час);
    СоответствиеСобытия.Вставить("МассивURLФайловВложений"  , Вложения);
    СоответствиеСобытия.Вставить("ОтправлятьУведомления"    , Истина);
    
    Результат = OPI_GoogleCalendar.СоздатьСобытие(Токен, Календарь, СоответствиеСобытия);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьСобытие");
    
    Событие   = Результат[UID];
    
    Проверка_ГКОбъект(Результат, Наименование, Описание);
      
    СоответствиеСобытия = Новый Соответствие;  
    СоответствиеСобытия.Вставить("Описание", ОписаниеИзм);
    
    Результат = OPI_GoogleCalendar.ИзменитьСобытие(Токен, Календарь, СоответствиеСобытия, Событие);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ИзменитьСобытие");
    
    Проверка_ГКОбъект(Результат, Наименование, ОписаниеИзм);
        
    Результат = OPI_GoogleCalendar.ПолучитьСобытие(Токен, Календарь, Событие);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСобытие");
    
    Проверка_ГКОбъект(Результат, Наименование, ОписаниеИзм);

    Результат = OPI_GoogleCalendar.ПереместитьСобытие(Токен, Календарь, Календарь, Событие);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПереместитьСобытие");
    
    Проверка_ГКОбъект(Результат, Наименование, ОписаниеИзм);
  
    Результат = OPI_GoogleCalendar.УдалитьСобытие(Токен, Календарь, Событие); 
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьСобытие");
       
    Проверка_Пусто(Результат);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура ГК_ПолучитьСписокСобытий() Экспорт
 
    Токен     = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_Token");    
    Календарь = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_Календарь");

    Результат = OPI_GoogleCalendar.ПолучитьСписокСобытий(Токен, Календарь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСписокСобытий");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Массив");
    
    OPI_Инструменты.Пауза(5);
        
КонецПроцедуры

#КонецОбласти

#Область GoogleDrive

Процедура ГД_ПолучитьСписокКаталогов() Экспорт
 
    MimeType  = "mimeType";
    Name      = "name";
    Имя       = "ОПИ";
    Токен     = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_Token");
    Результат = OPI_GoogleDrive.ПолучитьСписокКаталогов(Токен, Имя, Истина);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьСписокКаталогов");
    
    Результат = Результат[0];
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["files"]).ИмеетТип("Массив");
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[MimeType]).Равно("application/vnd.google-apps.folder");
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Name]).Заполнено();
    
    OPI_Инструменты.Пауза(5);
    Идентификатор = Результат["id"];
    
    OPI_ПолучениеДанныхТестов.ЗаписатьПараметр("GD_Каталог", Идентификатор);
    
    Результат   = OPI_GoogleDrive.ПолучитьИнформациюОбОбъекте(Токен, Идентификатор);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьИнформациюОбОбъекте");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[MimeType]).Равно("application/vnd.google-apps.folder");
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Name]).Заполнено();
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура ГД_ЗагрузитьУдалитьФайл() Экспорт
 
    Kind      = "kind";
    Content   = "content";
    MIME      = "MIME";
    MimeType  = "mimeType";
    Name      = "name";
    Id_       = "id";
    
    МассивУдаляемых = Новый Массив;
    Токен           = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_Token");
    Картинка        = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Картинка");
    КартинкаЗамены  = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Картинка2");
    Каталог         = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("GD_Каталог");
    
    Описание = OPI_GoogleDrive.ПолучитьОписаниеФайла();
    Описание.Вставить("Родитель", Каталог);
   
    Результат = OPI_GoogleDrive.ЗагрузитьФайл(Токен, Картинка, Описание);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ЗагрузитьФайл");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[MimeType]).Равно(Описание[MIME]);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Name]).Равно(Описание["Имя"]);

    Идентификатор = Результат[Id_];
    МассивУдаляемых.Добавить(Идентификатор);
    
    НовоеИмя  = "Скопированный файл.jpeg";
    Результат = OPI_GoogleDrive.СкоприроватьОбъект(Токен, Идентификатор, НовоеИмя, "root");
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СкоприроватьОбъект");
    
    OPI_Инструменты.Пауза(5);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[MimeType]).Равно(Описание[MIME]);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Name]).Равно(НовоеИмя);
       
    МассивУдаляемых.Добавить(Результат[Id_]);
    
    Результат = OPI_GoogleDrive.СкачатьФайл(Токен, Идентификатор);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СкачатьФайл");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат.Размер()).Равно(Картинка.Размер() + 2);
    OPI_Инструменты.Пауза(5);
    
    НовоеИмя  = "Обновленный";
    Результат = OPI_GoogleDrive.ОбновитьФайл(Токен, Идентификатор, КартинкаЗамены, НовоеИмя);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОбновитьФайл");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[MimeType]).Равно(Описание[MIME]);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Name]).Равно(НовоеИмя);

    OPI_Инструменты.Пауза(5);
    
    Комментарий = "Yo";
    Результат   = OPI_GoogleDrive.СоздатьКомментарий(Токен, Идентификатор, Комментарий);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьКомментарий");
  
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Content]).Равно(Комментарий);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат[Kind]).Равно("drive#comment");
    
    OPI_Инструменты.Пауза(5);
     
    Для Каждого Удаляемый Из МассивУдаляемых Цикл
        Результат = OPI_GoogleDrive.УдалитьОбъект(Токен, Удаляемый);    
        
        // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "УдалитьОбъект");
      
        OPI_ПолучениеДанныхТестов.ОжидаетЧто(ЗначениеЗаполнено(Результат)).Равно(Ложь);
        OPI_Инструменты.Пауза(2);
    КонецЦикла;
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура ГД_СоздатьУдалитьКомментарий() Экспорт
  
    Id_         = "id";
    Токен       = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Google_Token");
    Каталог     = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("GD_Каталог");
    Картинка    = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Картинка");
    
    Описание = OPI_GoogleDrive.ПолучитьОписаниеФайла();
    Описание.Вставить("Родитель", Каталог);
    
    Результат     = OPI_GoogleDrive.ЗагрузитьФайл(Токен, Картинка, Описание);
    Идентификатор = Результат[Id_];
    
    Комментарий   = "Новый комментарий";
    Результат     = OPI_GoogleDrive.СоздатьКомментарий(Токен, Идентификатор, Комментарий);
    
    Результат = OPI_GoogleDrive.УдалитьОбъект(Токен, Идентификатор);
    
КонецПроцедуры

#КонецОбласти

#Область Twitter

Процедура Твиттер_ПолучитьСсылкуАвторизации() Экспорт
 
    Параметры = ПолучитьПараметрыТвиттер();
    Результат = OPI_Twitter.ПолучитьСсылкуАвторизации(Параметры);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Строка").Заполнено();
    
    OPI_ПолучениеДанныхТестов.ЗаписатьПараметр("Twitter_URL", Результат);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура Твиттер_ОбновитьТокен() Экспорт
 
    Параметры = ПолучитьПараметрыТвиттер();
    Результат = OPI_Twitter.ОбновитьТокен(Параметры);
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["access_token"]).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["refresh_token"]).Заполнено();
        
    Рефреш = Результат["refresh_token"];
    Токен  = Результат["access_token"];
    
    Если ЗначениеЗаполнено(Рефреш) И Не Рефреш = "null" Тогда   
        OPI_ПолучениеДанныхТестов.ЗаписатьПараметр("Twitter_Refresh", Рефреш);
    КонецЕсли;
    
    Если ЗначениеЗаполнено(Токен) И Не Токен = "null" Тогда
        OPI_ПолучениеДанныхТестов.ЗаписатьПараметр("Twitter_Token"  , Токен);
    КонецЕсли;
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура Твиттер_СоздатьТекстовыйТвит() Экспорт
 
    Параметры = ПолучитьПараметрыТвиттер();
    Текст     = "Тестовый твитт" + Строка(Новый УникальныйИдентификатор);
    
    Результат = OPI_Twitter.СоздатьТекстовыйТвит(Текст, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьТекстовыйТвит");
    
    Проверка_ТвиттерТекст(Результат, Текст);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура Твиттер_СоздатьТвитСКартинкой() Экспорт
 
    Параметры = ПолучитьПараметрыТвиттер();
    Текст     = "Тестовый твитт" + Строка(Новый УникальныйИдентификатор);
    Картинка  = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Картинка");
    ИВФ       = ПолучитьИмяВременногоФайла("png");
    Картинка.Записать(ИВФ);
   
    Результат = OPI_Twitter.СоздатьТвитКартинки(Текст, Картинка, Параметры); 
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьТвитКартинки");
    
    Проверка_ТвиттерТекст(Результат, Текст);    
    
    Результат = OPI_Twitter.СоздатьТвитКартинки(Текст, ИВФ, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьТвитКартинки");
    
    Проверка_ТвиттерТекст(Результат, Текст);
    
    УдалитьФайлы(ИВФ);
    
    OPI_Инструменты.Пауза(20);
    
КонецПроцедуры

Процедура Твиттер_СоздатьТвитСВидео() Экспорт
 
    Параметры = ПолучитьПараметрыТвиттер();
    Текст     = "Тестовый твитт" + Строка(Новый УникальныйИдентификатор);
    Видео     = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Видео");
    ИВФ       = ПолучитьИмяВременногоФайла("mp4");
    Видео.Записать(ИВФ);
   
    Результат = OPI_Twitter.СоздатьТвитВидео(Текст, Видео, Параметры);    
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьТвитВидео");
    
    Проверка_ТвиттерТекст(Результат, Текст);    
    
    Результат = OPI_Twitter.СоздатьТвитВидео(Текст, ИВФ, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьТвитВидео");
    
    Проверка_ТвиттерТекст(Результат, Текст);
    
    УдалитьФайлы(ИВФ);
    
    OPI_Инструменты.Пауза(20);
    
КонецПроцедуры

Процедура Твиттер_СоздатьТвитСГиф() Экспорт
 
    Параметры = ПолучитьПараметрыТвиттер();
    Текст     = "Тестовый твитт" + Строка(Новый УникальныйИдентификатор);
    Гифка     = OPI_ПолучениеДанныхТестов.ПолучитьДвоичные("Гифка");
    ИВФ       = ПолучитьИмяВременногоФайла("gif");
    Гифка.Записать(ИВФ);
   
    Результат = OPI_Twitter.СоздатьТвитГифки(Текст, Гифка, Параметры);   
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьТвитГифки");
     
    Проверка_ТвиттерТекст(Результат, Текст);    
    
    Результат = OPI_Twitter.СоздатьТвитГифки(Текст, ИВФ, Параметры);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьТвитГифки");
    
    Проверка_ТвиттерТекст(Результат, Текст);
    
    УдалитьФайлы(ИВФ);
    
    OPI_Инструменты.Пауза(20);
    
КонецПроцедуры

Процедура Твиттер_СоздатьТвитСОпросом() Экспорт
 
    Параметры       = ПолучитьПараметрыТвиттер();
    Текст           = "Тестовый твитт" + Строка(Новый УникальныйИдентификатор);
    МассивОтветов   = Новый Массив;
    МассивОтветов.Добавить("Вариант 1");
    МассивОтветов.Добавить("Вариант 2");
   
    Результат = OPI_Twitter.СоздатьТвитОпрос(Текст, МассивОтветов, 60, Параметры);
 
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "СоздатьТвитОпрос");
    
    Проверка_ТвиттерТекст(Результат, Текст);
    
    OPI_Инструменты.Пауза(20);
    
КонецПроцедуры

#КонецОбласти

#Область Viber

Процедура Вайбер_ПолучитьИнформациюОКанале() Экспорт
 
    Токен     = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_ТокенКанала");    
    Результат = OPI_Viber.ПолучитьИнформациюОКанале(Токен);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьИнформациюОКанале");
        
    Проверка_ВайберОк(Результат);

    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Вайбер_ПолучитьДанныеПользователя() Экспорт
 
    Токен        = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_ТокенКанала"); 
    Пользователь = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_АдминКанала");
    Результат    = OPI_Viber.ПолучитьДанныеПользователя(Токен, Пользователь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьДанныеПользователя");
        
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["chat_hostname"]).Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["status_message"]).Заполнено();
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Вайбер_ПолучитьОнлайнПользователей() Экспорт
 
    Токен        = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_ТокенКанала"); 
    Пользователь = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_Пользователь");
    Результат    = OPI_Viber.ПолучитьОнлайнПользователей(Токен, Пользователь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ПолучитьОнлайнПользователей");
        
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["users"]).ИмеетТип("Массив");
    Проверка_ВайберОк(Результат);
    
    OPI_Инструменты.Пауза(5);

КонецПроцедуры

Процедура Вайбер_ОтправитьТекстовоеСообщение() Экспорт
 
    Текст         = "Тестовое сообщение";
    ТокенКанал    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_ТокенКанала");
    ТокенБота     = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_Токен");   
    Пользователь  = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_Пользователь");
    Администратор = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_АдминКанала");
    
    МассивКнопок  = Новый Массив;
    МассивКнопок.Добавить("Кнопка 1");
    МассивКнопок.Добавить("Кнопка 2");
    МассивКнопок.Добавить("Кнопка 3");
    
    Клавиатура = OPI_Viber.СформироватьКлавиатуруИзМассиваКнопок(МассивКнопок);
 
    Результат  = OPI_Viber.ОтправитьТекстовоеСообщение(ТокенБота, Текст, Пользователь, Ложь, Клавиатура);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьТекстовоеСообщение");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["message_token"]).Заполнено();
    Проверка_ВайберОк(Результат);
    
    Результат  = OPI_Viber.ОтправитьТекстовоеСообщение(ТокенКанал, Текст, Администратор, Истина, Клавиатура);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьТекстовоеСообщение");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["message_token"]).Заполнено();
    Проверка_ВайберОк(Результат);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура Вайбер_ОтправитьКартинку() Экспорт

    Текст         = "Тестовое сообщение";
    Картинка      = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Картинка");
    ТокенКанал    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_ТокенКанала");
    ТокенБота     = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_Токен");   
    Пользователь  = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_Пользователь");
    Администратор = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_АдминКанала");
     
    Результат  = OPI_Viber.ОтправитьКартинку(ТокенБота, Картинка, Пользователь, Ложь, Текст);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьКартинку");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["message_token"]).Заполнено();
    Проверка_ВайберОк(Результат);
    
    Результат  = OPI_Viber.ОтправитьКартинку(ТокенКанал, Картинка, Администратор, Истина, Текст);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьКартинку");
        
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["message_token"]).Заполнено();
    Проверка_ВайберОк(Результат);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура Вайбер_ОтправитьФайл() Экспорт
  
    Документ      = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Документ");
    ТокенКанал    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_ТокенКанала");
    ТокенБота     = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_Токен");   
    Пользователь  = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_Пользователь");
    Администратор = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_АдминКанала");
       
    Результат  = OPI_Viber.ОтправитьФайл(ТокенБота, Документ, Пользователь, Ложь, "docx");
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьФайл");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["message_token"]).Заполнено();
    Проверка_ВайберОк(Результат);
    
    Результат  = OPI_Viber.ОтправитьФайл(ТокенКанал, Документ, Администратор, Истина, "docx");
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьФайл");
        
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["message_token"]).Заполнено();
    Проверка_ВайберОк(Результат);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура Вайбер_ОтправитьКонтакт() Экспорт
 
    Имя           = "Петр Петров";
    Телефон       = "+123456789";
    ТокенКанал    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_ТокенКанала");
    ТокенБота     = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_Токен");   
    Пользователь  = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_Пользователь");
    Администратор = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_АдминКанала");
         
    Результат  = OPI_Viber.ОтправитьКонтакт(ТокенБота, Имя, Телефон, Пользователь, Ложь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьКонтакт");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["message_token"]).Заполнено();
    Проверка_ВайберОк(Результат);
    
    Результат  = OPI_Viber.ОтправитьКонтакт(ТокенКанал, Имя, Телефон, Администратор, Истина);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьКонтакт");
        
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["message_token"]).Заполнено();
    Проверка_ВайберОк(Результат);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура Вайбер_ОтправитьЛокацию() Экспорт

    Широта        = "48.87373649724122";
    Долгота       = "2.2954639195323967";
    ТокенКанал    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_ТокенКанала");
    ТокенБота     = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_Токен");   
    Пользователь  = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_Пользователь");
    Администратор = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_АдминКанала");
         
    Результат  = OPI_Viber.ОтправитьЛокацию(ТокенБота, Широта, Долгота, Пользователь, Ложь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьЛокацию");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["message_token"]).Заполнено();
    Проверка_ВайберОк(Результат);
    
    Результат  = OPI_Viber.ОтправитьЛокацию(ТокенКанал, Широта, Долгота, Администратор, Истина);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьЛокацию");
        
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["message_token"]).Заполнено();
    Проверка_ВайберОк(Результат);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

Процедура Вайбер_ОтправитьСсылку() Экспорт

    URL           = "https://github.com/Bayselonarrend/OpenIntegrations";
    ТокенКанал    = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_ТокенКанала");
    ТокенБота     = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_Токен");   
    Пользователь  = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_Пользователь");
    Администратор = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Вайбер_АдминКанала");
         
    Результат  = OPI_Viber.ОтправитьСсылку(ТокенБота, URL, Пользователь, Ложь);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьСсылку");
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["message_token"]).Заполнено();
    Проверка_ВайберОк(Результат);
    
    Результат  = OPI_Viber.ОтправитьСсылку(ТокенКанал, URL, Администратор, Истина);
    
    // !OInt OPI_ПолучениеДанныхТестов.ЗаписатьЛог(Результат, "ОтправитьСсылку");
        
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["message_token"]).Заполнено();
    Проверка_ВайберОк(Результат);
    
    OPI_Инструменты.Пауза(5);
    
КонецПроцедуры

#КонецОбласти

#КонецОбласти

#КонецОбласти

#Область СлужебныеПроцедурыИФункции

Функция ПолучитьПараметрыВК() 
    
    Параметры   = Новый Структура;
    НомерГруппы = OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ВК_НомерГруппы");
    
    Параметры.Вставить("access_token"  , OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ВК_Токен"));
    Параметры.Вставить("owner_id"      , "-" + НомерГруппы);
    Параметры.Вставить("app_id"        , OPI_ПолучениеДанныхТестов.ПолучитьПараметр("ВК_Приложение"));
    Параметры.Вставить("group_id"      , НомерГруппы);
    
    Возврат Параметры;
    
КонецФункции

Функция ПолучитьПараметрыТвиттер() 
    
    Параметры = Новый Соответствие;
              
    Параметры.Вставить("redirect_uri"          , OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Twitter_Redirect"));
    Параметры.Вставить("client_id"             , OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Twitter_ClinetID"));
    Параметры.Вставить("client_secret"         , OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Twitter_ClientSecret"));
    Параметры.Вставить("access_token"          , OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Twitter_Token"));
    Параметры.Вставить("refresh_token"         , OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Twitter_Refresh"));
    Параметры.Вставить("oauth_token"           , OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Twitter_OAuthToken"));
    Параметры.Вставить("oauth_token_secret"    , OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Twitter_OAuthSecret"));
    
    Параметры.Вставить("oauth_consumer_key"    
        , OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Twitter_OAuthConsumerKey"));
    Параметры.Вставить("oauth_consumer_secret" 
        , OPI_ПолучениеДанныхТестов.ПолучитьПараметр("Twitter_OAuthConsumerSecret"));

    Возврат Параметры;
    
КонецФункции

#Область Проверки

Процедура Проверка_ТелеграмИстина(Знач Результат)
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["ok"]).Равно(Истина);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["result"]).Равно(Истина);
        
КонецПроцедуры

Процедура Проверка_ВКИстина(Знач Результат)
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["response"]).ИмеетТип("Число").Равно(1);
    
КонецПроцедуры

Процедура Проверка_ГКОбъект(Знач Результат, Знач Наименование, Знач Описание)
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие");
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["summary"]).Равно(Наименование);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["description"]).Равно(Описание);
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["id"]).ИмеетТип("Строка").Заполнено();
    
КонецПроцедуры

Процедура Проверка_Пусто(Знач Результат)   
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(ЗначениеЗаполнено(Результат)).Равно(Ложь);
КонецПроцедуры

Процедура Проверка_ТвиттерТекст(Знач Результат, Знач Текст)
    
    ТекстОтвета = Результат["data"]["text"];
    ТекстОтвета = Лев(ТекстОтвета, СтрДлина(Текст));
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат).ИмеетТип("Соответствие").Заполнено();
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(ТекстОтвета).Равно(Текст);

КонецПроцедуры

Процедура Проверка_ВайберОк(Знач Результат)
    
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["status_message"]).Равно("ok");
    OPI_ПолучениеДанныхТестов.ОжидаетЧто(Результат["status"]).Равно(0);

КонецПроцедуры

#КонецОбласти

#КонецОбласти
